# coding: utf-8

"""
    Passage Management API

    Passage's management API to manage your Passage apps and users.

    The version of the OpenAPI document: 1
    Contact: support@passage.id
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from passageidentity.openapi_client.models.font_family import FontFamily
from typing import Optional, Set
from typing_extensions import Self

class ElementCustomization(BaseModel):
    """
    ElementCustomization
    """ # noqa: E501
    passage_container_background_color: Optional[StrictStr] = Field(default=None, description="Container background color in hex. Default is `#ffffff` in light mode & `#383838` in dark mode. ")
    passage_container_max_width: Optional[StrictInt] = Field(default=300, description="Maximum width of container (px)")
    passage_input_box_background_color: Optional[StrictStr] = Field(default=None, description="Input box background color in hex. Default is `#ffffff` in light mode & `#4b4b4b` in dark mode. ")
    passage_input_box_border_radius: Optional[StrictInt] = Field(default=5, description="Input box border radius (px)")
    passage_header_font_family: Optional[FontFamily] = FontFamily.HELVETICA
    passage_body_font_family: Optional[FontFamily] = FontFamily.HELVETICA
    passage_header_text_color: Optional[StrictStr] = Field(default=None, description="Header text color in hex. Default is `#222222` in light mode & `#f3f3f3` in dark mode. ")
    passage_body_text_color: Optional[StrictStr] = Field(default=None, description="Body text color in hex. Default is `#222222` in light mode & `#f3f3f3` in dark mode. ")
    passage_primary_button_background_color: Optional[StrictStr] = Field(default='#121212', description="Primary button background colour (hex)")
    passage_primary_button_text_color: Optional[StrictStr] = Field(default='#f3f3f3', description="Primary button font colour (hex)")
    passage_primary_button_hover_color: Optional[StrictStr] = Field(default='#4d4d4d', description="Primary button background on hover (hex)")
    passage_primary_button_border_radius: Optional[StrictInt] = Field(default=5, description="Primary button border radius (px)")
    passage_primary_button_border_color: Optional[StrictStr] = Field(default='#121212', description="Primary button border color")
    passage_primary_button_border_width: Optional[StrictInt] = Field(default=0, description="Primary button border width (px)")
    passage_secondary_button_background_color: Optional[StrictStr] = Field(default='#ffffff', description="Secondary button background colour (hex)")
    passage_secondary_button_text_color: Optional[StrictStr] = Field(default='#222222', description="Secondary button font colour (hex)")
    passage_secondary_button_hover_color: Optional[StrictStr] = Field(default='#d7d7d7', description="Secondary button background on hover (hex)")
    passage_secondary_button_border_radius: Optional[StrictInt] = Field(default=5, description="Secondary button border radius (px)")
    passage_secondary_button_border_color: Optional[StrictStr] = Field(default='#d7d7d7', description="Secondary button border color")
    passage_secondary_button_border_width: Optional[StrictInt] = Field(default=1, description="Secondary button border width (px)")
    __properties: ClassVar[List[str]] = ["passage_container_background_color", "passage_container_max_width", "passage_input_box_background_color", "passage_input_box_border_radius", "passage_header_font_family", "passage_body_font_family", "passage_header_text_color", "passage_body_text_color", "passage_primary_button_background_color", "passage_primary_button_text_color", "passage_primary_button_hover_color", "passage_primary_button_border_radius", "passage_primary_button_border_color", "passage_primary_button_border_width", "passage_secondary_button_background_color", "passage_secondary_button_text_color", "passage_secondary_button_hover_color", "passage_secondary_button_border_radius", "passage_secondary_button_border_color", "passage_secondary_button_border_width"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ElementCustomization from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ElementCustomization from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "passage_container_background_color": obj.get("passage_container_background_color"),
            "passage_container_max_width": obj.get("passage_container_max_width") if obj.get("passage_container_max_width") is not None else 300,
            "passage_input_box_background_color": obj.get("passage_input_box_background_color"),
            "passage_input_box_border_radius": obj.get("passage_input_box_border_radius") if obj.get("passage_input_box_border_radius") is not None else 5,
            "passage_header_font_family": obj.get("passage_header_font_family") if obj.get("passage_header_font_family") is not None else FontFamily.HELVETICA,
            "passage_body_font_family": obj.get("passage_body_font_family") if obj.get("passage_body_font_family") is not None else FontFamily.HELVETICA,
            "passage_header_text_color": obj.get("passage_header_text_color"),
            "passage_body_text_color": obj.get("passage_body_text_color"),
            "passage_primary_button_background_color": obj.get("passage_primary_button_background_color") if obj.get("passage_primary_button_background_color") is not None else '#121212',
            "passage_primary_button_text_color": obj.get("passage_primary_button_text_color") if obj.get("passage_primary_button_text_color") is not None else '#f3f3f3',
            "passage_primary_button_hover_color": obj.get("passage_primary_button_hover_color") if obj.get("passage_primary_button_hover_color") is not None else '#4d4d4d',
            "passage_primary_button_border_radius": obj.get("passage_primary_button_border_radius") if obj.get("passage_primary_button_border_radius") is not None else 5,
            "passage_primary_button_border_color": obj.get("passage_primary_button_border_color") if obj.get("passage_primary_button_border_color") is not None else '#121212',
            "passage_primary_button_border_width": obj.get("passage_primary_button_border_width") if obj.get("passage_primary_button_border_width") is not None else 0,
            "passage_secondary_button_background_color": obj.get("passage_secondary_button_background_color") if obj.get("passage_secondary_button_background_color") is not None else '#ffffff',
            "passage_secondary_button_text_color": obj.get("passage_secondary_button_text_color") if obj.get("passage_secondary_button_text_color") is not None else '#222222',
            "passage_secondary_button_hover_color": obj.get("passage_secondary_button_hover_color") if obj.get("passage_secondary_button_hover_color") is not None else '#d7d7d7',
            "passage_secondary_button_border_radius": obj.get("passage_secondary_button_border_radius") if obj.get("passage_secondary_button_border_radius") is not None else 5,
            "passage_secondary_button_border_color": obj.get("passage_secondary_button_border_color") if obj.get("passage_secondary_button_border_color") is not None else '#d7d7d7',
            "passage_secondary_button_border_width": obj.get("passage_secondary_button_border_width") if obj.get("passage_secondary_button_border_width") is not None else 1
        })
        return _obj





# coding: utf-8

"""
    Passage Management API

    Passage's management API to manage your Passage apps and users.

    The version of the OpenAPI document: 1
    Contact: support@passage.id
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class Technologies(str, Enum):
    """
    Technologies
    """

    """
    allowed enum values
    """
    REACT = 'react'
    GO = 'go'
    VUE = 'vue'
    ANGULAR = 'angular'
    PYTHON = 'python'
    JAVASCRIPT = 'javascript'
    IOS = 'ios'
    ANDROID = 'android'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Technologies from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

# flake8: noqa
"""
Passage Management API

Passage's management API to manage your Passage apps and users.

The version of the OpenAPI document: 1
Contact: support@passage.id
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from passageidentity.models.update_magic_link_auth_method import (
    UpdateMagicLinkAuthMethod,
)
from passageidentity.models.update_passkey_auth_method import UpdatePasskeysAuthMethod
from passageidentity.models.update_otp_auth_method import UpdateOtpAuthMethod
from passageidentity.models.magic_link_args import MagicLinkArgs
from passageidentity.models.magic_link_options import MagicLinkOptions



"""Provides helper functions for interacting with the Passage Identity API."""

import re
from http import HTTPStatus

from requests.sessions import Request

from passageidentity import requests
from passageidentity.errors import PassageError

BEARER_PATTERN = r"Bearer ([^\s,]+)"


def extract_token(auth_header: str) -> str:
    """Extract the JWT from an Authorization header."""
    expression = re.escape(BEARER_PATTERN)
    match = re.search(expression, auth_header)

    if match:
        return match.group(1)

    msg = "No Passage authorization header."
    raise PassageError(msg)


def get_auth_token_from_request(request: Request, auth_strategy: int) -> str:
    """Get the auth token from a request.

    Checks the Authorization header first, then the psg_auth_token cookie.
    """
    if auth_strategy == 2:  # noqa: PLR2004
        auth_header = request.headers["Authorization"]
        expression = re.escape(BEARER_PATTERN)
        match = re.search(expression, auth_header)

        if match:
            return match.group(1)

        msg = "No Passage authorization header."
        raise PassageError(msg)

    if "psg_auth_token" not in request.cookies:
        msg = "No Passage authentication token."
        raise PassageError(msg)

    return request.cookies["psg_auth_token"]


def fetch_app(app_id: str) -> dict:
    """Fetch the public key for the given app id from Passage."""
    # unauthenticated request to get the public key
    r = requests.get(f"https://api.passage.id/v1/apps/{app_id}")

    if r.status_code != HTTPStatus.OK:
        msg = f"Could not fetch app information for app id {app_id}"
        raise PassageError(msg)

    return r.json()["app"]



# coding: utf-8

"""
    Passage Management API

    Passage's management API to manage your Passage apps and users.

    The version of the OpenAPI document: 1
    Contact: support@passage.id
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class UserMetadataFieldType(str, Enum):
    """
    UserMetadataFieldType
    """

    """
    allowed enum values
    """
    STRING = 'string'
    BOOLEAN = 'boolean'
    INTEGER = 'integer'
    DATE = 'date'
    PHONE = 'phone'
    EMAIL = 'email'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of UserMetadataFieldType from a JSON string"""
        return cls(json.loads(json_str))





"""Provides the Passage class for interacting with the Passage API."""

from __future__ import annotations

from typing import TYPE_CHECKING, cast

import typing_extensions

from passageidentity.auth import Auth
from passageidentity.errors import PassageError
from passageidentity.helper import get_auth_token_from_request
from passageidentity.models.magic_link_args import MagicLinkWithEmailArgs, MagicLinkWithPhoneArgs, MagicLinkWithUserArgs
from passageidentity.models.magic_link_options import MagicLinkOptions
from passageidentity.openapi_client.models.magic_link_channel import MagicLinkChannel
from passageidentity.user import User

from .openapi_client.api import (
    AppsApi,
)
from .openapi_client.models import (
    CreateMagicLinkRequest,
    CreateUserRequest,
    MagicLinkType,
)

if TYPE_CHECKING:
    from requests.sessions import Request

    from .openapi_client.models import (
        AppInfo,
        UpdateUserRequest,
        UserInfo,
        WebAuthnDevices,
    )


class Passage:
    """Passage class for interacting with the Passage API."""

    COOKIE_AUTH = 1
    HEADER_AUTH = 2

    def __init__(self, app_id: str, api_key: str = "", auth_strategy: int = COOKIE_AUTH) -> None:
        """Initialize a new Passage instance."""
        if not app_id:
            msg = "A Passage app ID is required. Please include {app_id=YOUR_APP_ID, api_key=YOUR_API_KEY}."
            raise PassageError(msg)

        self.app_id: str = app_id
        self.passage_apikey: str = api_key
        self.auth_strategy: int = auth_strategy
        self.request_headers = {"Authorization": f"Bearer {api_key}"}

        self.auth = Auth(app_id, self.request_headers)
        self.user = User(app_id, self.request_headers)

    @typing_extensions.deprecated("Passage.validateJwt() will be deprecated. Use Passage.auth.validate_jwt() instead.")
    def validateJwt(self, token: str):  # noqa: ANN201, N802
        """Verify the JWT and return the user ID for the authenticated user, or throw a PassageError.

        Takes the place of the deprecated authenticateRequest() function.
        """
        return self.auth.validate_jwt(token)

    @typing_extensions.deprecated(
        "Passage.authenticateRequest() will be deprecated. Use Passage.auth.validate_jwt() instead.",
    )
    def authenticateRequest(self, request: Request) -> str | PassageError:  # noqa: N802
        """Authenticate a Flask or Django request that uses Passage for authentication.

        This function will verify the JWT and return the user ID for the authenticated user, or throw
        a PassageError.
        """
        # check for authorization header
        token = get_auth_token_from_request(request, self.auth_strategy)
        if not token:
            msg = "Could not find JWT."
            raise PassageError(msg)

        # load and parse the JWT
        try:
            return self.auth.validate_jwt(token)
        except Exception as e:
            msg = f"JWT is not valid: {e}"
            raise PassageError(msg) from e

    @typing_extensions.deprecated(
        "Passage.authenticateJWT() will be deprecated. Use Passage.auth.validate_jwt() instead.",
    )
    def authenticateJWT(self, token: str) -> str | PassageError:  # noqa: N802
        """Authenticate a JWT from Passage.

        This function will verify the JWT and return the user ID for the authenticated user, or throw a PassageError.
        This function can be used to authenticate JWTs from Passage if they are not sent in a typical cookie or
        authorization header.
        """
        return self.auth.validate_jwt(token)

    @typing_extensions.deprecated(
        "Passage.createMagicLink() will be deprecated. Use Passage.auth.create_magic_link() instead.",
    )
    def createMagicLink(  # noqa: N802
        self,
        magicLinkAttributes: CreateMagicLinkRequest,  # noqa: N803
    ) -> MagicLinkType | PassageError:
        """Create Passage MagicLink."""
        # if no api key, fail
        if self.passage_apikey == "":
            msg = "No Passage API key provided."
            raise PassageError(msg)

        magic_link_attrs_dict = (
            magicLinkAttributes.to_dict()
            if isinstance(magicLinkAttributes, CreateMagicLinkRequest)
            else magicLinkAttributes
        )

        if email := magic_link_attrs_dict.get("email"):
            args = MagicLinkWithEmailArgs()
            args.email = email
        elif phone := magic_link_attrs_dict.get("phone"):
            args = MagicLinkWithPhoneArgs()
            args.phone = phone
        elif user_id := magic_link_attrs_dict.get("user_id"):
            args = MagicLinkWithUserArgs()
            args.user_id = user_id
            args.channel = magic_link_attrs_dict.get("channel") or MagicLinkChannel.EMAIL
        else:
            msg = "Could not create a magic link for this app: must provide one of: email, phone, userID"
            raise TypeError(msg)

        args.send = magic_link_attrs_dict.get("send") or False
        args.type = magic_link_attrs_dict.get("type") or MagicLinkType.LOGIN

        options = MagicLinkOptions()
        options.language = magic_link_attrs_dict.get("language")
        options.magic_link_path = magic_link_attrs_dict.get("magic_link_path")
        options.redirect_url = magic_link_attrs_dict.get("redirect_url")
        options.ttl = magic_link_attrs_dict.get("ttl")

        return self.auth.create_magic_link(args, options)  # type: ignore[attr-defined]

    @typing_extensions.deprecated("Passage.getApp() will be removed without replacement.")
    def getApp(self) -> AppInfo | PassageError:  # noqa: N802
        """Use Passage API to get info for their app."""
        client = AppsApi()
        return client.get_app(self.app_id).app

    @typing_extensions.deprecated("Passage.getUser() will be deprecated. Use Passage.user.get() instead.")
    def getUser(self, user_id: str) -> UserInfo | PassageError:  # noqa: N802
        """Use Passage API to get info for a user, look up by user ID."""
        return self.user.get(user_id)

    @typing_extensions.deprecated(
        "Passage.getUserByIdentifier() will be deprecated. Use Passage.user.get_by_identifier() instead.",
    )
    def getUserByIdentifier(self, userIdentifier: str) -> UserInfo | PassageError:  # noqa: N802, N803
        """Use Passage API to get info for a user, look up by user identifier."""
        return self.user.get_by_identifier(userIdentifier)

    @typing_extensions.deprecated(
        "Passage.listUserDevices() will be deprecated. Use Passage.user.list_devices() instead.",
    )
    def listUserDevices(  # noqa: N802
        self,
        user_id: str,
    ) -> list[WebAuthnDevices] | PassageError:
        """Use Passage API to list user devices, look up by user ID."""
        return self.user.list_devices(user_id)

    @typing_extensions.deprecated(
        "Passage.deleteUserDevice() will be deprecated. Use Passage.user.revoke_device() instead.",
    )
    def deleteUserDevice(  # noqa: N802
        self,
        user_id: str,
        device_id: str,
    ) -> bool | PassageError:
        """Use Passage API to revoke user devices, look up by user ID."""
        self.user.revoke_device(user_id, device_id)
        return True

    @typing_extensions.deprecated(
        "Passage.revokeUserDevice() will be deprecated. Use Passage.user.revoke_device() instead.",
    )
    def revokeUserDevice(  # noqa: N802
        self,
        user_id: str,
        device_id: str,
    ) -> bool | PassageError:
        """Use Passage API to revoke user devices, look up by user ID."""
        self.user.revoke_device(user_id, device_id)
        return True

    @typing_extensions.deprecated(
        "Passage.revokeUserRefreshTokens() will be deprecated. Use Passage.user.revoke_refresh_tokens() instead.",
    )
    def revokeUserRefreshTokens(self, user_id: str) -> bool | PassageError:  # noqa: N802
        """Use Passage API to revoke all of a user's refresh tokens, look up by user ID."""
        self.user.revoke_refresh_tokens(user_id)
        return True

    @typing_extensions.deprecated(
        "Passage.signOut() will be deprecated. Use Passage.user.revoke_refresh_tokens() instead.",
    )
    def signOut(  # noqa: N802
        self,
        user_id: str,
    ) -> bool | PassageError:
        """Use Passage API to revoke all of a user's refresh tokens, look up by user ID."""
        self.user.revoke_refresh_tokens(user_id)
        return True

    @typing_extensions.deprecated("Passage.activateUser() will be deprecated. Use Passage.user.activate() instead.")
    def activateUser(self, user_id: str) -> UserInfo | PassageError:  # noqa: N802
        """Activate Passage User."""
        return self.user.activate(user_id)

    @typing_extensions.deprecated("Passage.deactivateUser() will be deprecated. Use Passage.user.deactivate() instead.")
    def deactivateUser(self, user_id: str) -> UserInfo | PassageError:  # noqa: N802
        """Deactivate Passage User."""
        return self.user.deactivate(user_id)

    @typing_extensions.deprecated("Passage.updateUser() will be deprecated. Use Passage.user.update() instead.")
    def updateUser(  # noqa: N802
        self,
        user_id: str,
        attributes: UpdateUserRequest,
    ) -> UserInfo | PassageError:
        """Update Passage User."""
        return self.user.update(user_id, attributes)

    @typing_extensions.deprecated("Passage.deleteUser() will be deprecated. Use Passage.user.delete() instead.")
    def deleteUser(self, user_id: str) -> bool | PassageError:  # noqa: N802
        """Delete Passage User."""
        self.user.delete(user_id)
        return True

    @typing_extensions.deprecated("Passage.createUser() will be deprecated. Use Passage.user.create() instead.")
    def createUser(  # noqa: N802
        self,
        userAttributes: CreateUserRequest,  # noqa: N803
    ) -> UserInfo | PassageError:
        """Create Passage User."""
        if not ("phone" in userAttributes or "email" in userAttributes):  # type: ignore[dict-item]
            msg = "either phone or email must be provided to create the user"
            raise PassageError(msg)

        user_args = (
            cast(CreateUserRequest, CreateUserRequest.from_dict(userAttributes))
            if isinstance(userAttributes, dict)
            else userAttributes
        )

        return self.user.create(user_args)



"""Defines options for creating a Magic Link."""

from __future__ import annotations


class MagicLinkOptions:
    """Options for creating a Magic Link."""

    language: str | None
    magic_link_path: str | None
    redirect_url: str | None
    ttl: int | None



"""Defines custom error classes for handling Passage-related errors."""

from __future__ import annotations

from typing import TYPE_CHECKING

import typing_extensions

if TYPE_CHECKING:
    from passageidentity.openapi_client.exceptions import ApiException


class PassageError(Exception):
    """Error class for handling Passage errors."""

    @typing_extensions.deprecated(
        "This should only be constructed by the Passage SDK. Use this type just for type checking.",
    )
    def __init__(
        self,
        message: str,
        status_code: int | None = None,
        status_text: str | None = None,
        body: dict | None = None,
        error_code: str | None = None,
    ) -> None:
        """Initialize the error with a message, status code, status text, and optional body."""
        self.message = message
        self.status_code = status_code
        self.status_text = status_text

        self.error_code = error_code
        self.error = None

        if body is not None:
            self.error = body["error"]
            self.error_code = body["code"]

    def __str__(self) -> str:
        """Return the error message."""
        return self.message

    @classmethod
    def from_response_error(cls, response_error: ApiException, message: str | None = None) -> PassageError:
        """Initialize the error with a response body and optional message."""
        if response_error.data is not None:
            data_dict = response_error.data.to_dict()
            error_code = data_dict.get("code")
            error_msg = data_dict.get("error")
            msg = ": ".join(filter(None, [message, error_msg]))
        else:
            error_code = None
            msg = str(response_error.body)

        return cls(message=msg, status_code=response_error.status, error_code=error_code)



# coding: utf-8

"""
Passage Management API

Passage's management API to manage your Passage apps and users.

The version of the OpenAPI document: 1
Contact: support@passage.id
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool
from pydantic import Field
from typing_extensions import Annotated
from passageidentity.openapi_client.models.ttl_display_unit import TtlDisplayUnit

try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


@DeprecationWarning
class UpdateMagicLinkAuthMethod(BaseModel):
    """
    UpdateMagicLinkAuthMethod
    """  # noqa: E501

    enabled: Optional[StrictBool] = None
    ttl: Optional[Annotated[int, Field(strict=True, ge=60)]] = Field(
        default=300, description="Maximum time (IN SECONDS) for the auth to expire."
    )
    ttl_display_unit: Optional[TtlDisplayUnit] = None
    __properties: ClassVar[List[str]] = ["enabled", "ttl", "ttl_display_unit"]

    model_config = {"populate_by_name": True, "validate_assignment": True}

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of UpdateMagicLinkAuthMethod from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={},
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of UpdateMagicLinkAuthMethod from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "enabled": obj.get("enabled"),
                "ttl": obj.get("ttl") if obj.get("ttl") is not None else 300,
                "ttl_display_unit": obj.get("ttl_display_unit"),
            }
        )
        return _obj


"""Initializes the Passage identity package."""

from .errors import PassageError
from .models import MagicLinkArgs, MagicLinkOptions
from .passage import Passage

__all__ = [
    "MagicLinkArgs",
    "MagicLinkOptions",
    "Passage",
    "PassageError",
]



# coding: utf-8

"""
    Passage Management API

    Passage's management API to manage your Passage apps and users.

    The version of the OpenAPI document: 1
    Contact: support@passage.id
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from passageidentity.openapi_client.models.auth_methods import AuthMethods
from passageidentity.openapi_client.models.element_customization import ElementCustomization
from passageidentity.openapi_client.models.layouts import Layouts
from passageidentity.openapi_client.models.technologies import Technologies
from passageidentity.openapi_client.models.user_metadata_field import UserMetadataField
from typing import Optional, Set
from typing_extensions import Self

class AppInfo(BaseModel):
    """
    AppInfo
    """ # noqa: E501
    additional_auth_origins: List[StrictStr]
    allowed_callback_urls: List[StrictStr] = Field(description="The valid URLs where users can be redirected after authentication.")
    allowed_identifier: StrictStr
    allowed_logout_urls: List[StrictStr] = Field(description="The valid URLs where users can be redirected after logging out.")
    application_login_uri: StrictStr = Field(description="A route within your application that redirects to the Authorization URL endpoint.")
    auth_fallback_method: StrictStr = Field(description="Deprecated Property. Please refer to `auth_methods` to view settings for individual authentication methods.")
    auth_fallback_method_ttl: StrictInt = Field(description="Deprecated Property. Please refer to `auth_methods` to view settings for individual authentication methods.")
    auth_methods: AuthMethods
    auth_origin: StrictStr
    auto_theme_enabled: StrictBool = Field(description="Deprecated Property. Please use `hosted_theme` to set hosted page theming instead.")
    created_at: datetime
    default_language: StrictStr
    id: StrictStr
    layouts: Layouts
    login_url: StrictStr
    light_logo_url: Optional[StrictStr] = None
    dark_logo_url: Optional[StrictStr] = None
    name: StrictStr
    hosted: StrictBool = Field(description="whether or not the app's login page is hosted by Passage")
    hosted_subdomain: StrictStr = Field(description="the subdomain of the app's hosted login page")
    hosted_theme: StrictStr
    id_token_lifetime: Optional[StrictInt] = None
    passage_branding: StrictBool
    profile_management: StrictBool
    public_signup: StrictBool
    redirect_url: StrictStr
    refresh_absolute_lifetime: StrictInt
    refresh_enabled: StrictBool
    refresh_inactivity_lifetime: StrictInt
    require_email_verification: StrictBool
    require_identifier_verification: StrictBool
    required_identifier: StrictStr
    role: StrictStr
    rsa_public_key: StrictStr
    secret: Optional[StrictStr] = Field(default=None, description="can only be retrieved by an app admin")
    session_timeout_length: StrictInt
    type: StrictStr
    user_metadata_schema: List[UserMetadataField]
    technologies: List[Technologies]
    element_customization: ElementCustomization
    element_customization_dark: ElementCustomization
    __properties: ClassVar[List[str]] = ["additional_auth_origins", "allowed_callback_urls", "allowed_identifier", "allowed_logout_urls", "application_login_uri", "auth_fallback_method", "auth_fallback_method_ttl", "auth_methods", "auth_origin", "auto_theme_enabled", "created_at", "default_language", "id", "layouts", "login_url", "light_logo_url", "dark_logo_url", "name", "hosted", "hosted_subdomain", "hosted_theme", "id_token_lifetime", "passage_branding", "profile_management", "public_signup", "redirect_url", "refresh_absolute_lifetime", "refresh_enabled", "refresh_inactivity_lifetime", "require_email_verification", "require_identifier_verification", "required_identifier", "role", "rsa_public_key", "secret", "session_timeout_length", "type", "user_metadata_schema", "technologies", "element_customization", "element_customization_dark"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['complete', 'flex']):
            raise ValueError("must be one of enum values ('complete', 'flex')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AppInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of auth_methods
        if self.auth_methods:
            _dict['auth_methods'] = self.auth_methods.to_dict()
        # override the default output from pydantic by calling `to_dict()` of layouts
        if self.layouts:
            _dict['layouts'] = self.layouts.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in user_metadata_schema (list)
        _items = []
        if self.user_metadata_schema:
            for _item_user_metadata_schema in self.user_metadata_schema:
                if _item_user_metadata_schema:
                    _items.append(_item_user_metadata_schema.to_dict())
            _dict['user_metadata_schema'] = _items
        # override the default output from pydantic by calling `to_dict()` of element_customization
        if self.element_customization:
            _dict['element_customization'] = self.element_customization.to_dict()
        # override the default output from pydantic by calling `to_dict()` of element_customization_dark
        if self.element_customization_dark:
            _dict['element_customization_dark'] = self.element_customization_dark.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AppInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "additional_auth_origins": obj.get("additional_auth_origins"),
            "allowed_callback_urls": obj.get("allowed_callback_urls"),
            "allowed_identifier": obj.get("allowed_identifier"),
            "allowed_logout_urls": obj.get("allowed_logout_urls"),
            "application_login_uri": obj.get("application_login_uri"),
            "auth_fallback_method": obj.get("auth_fallback_method"),
            "auth_fallback_method_ttl": obj.get("auth_fallback_method_ttl"),
            "auth_methods": AuthMethods.from_dict(obj["auth_methods"]) if obj.get("auth_methods") is not None else None,
            "auth_origin": obj.get("auth_origin"),
            "auto_theme_enabled": obj.get("auto_theme_enabled"),
            "created_at": obj.get("created_at"),
            "default_language": obj.get("default_language"),
            "id": obj.get("id"),
            "layouts": Layouts.from_dict(obj["layouts"]) if obj.get("layouts") is not None else None,
            "login_url": obj.get("login_url"),
            "light_logo_url": obj.get("light_logo_url"),
            "dark_logo_url": obj.get("dark_logo_url"),
            "name": obj.get("name"),
            "hosted": obj.get("hosted"),
            "hosted_subdomain": obj.get("hosted_subdomain"),
            "hosted_theme": obj.get("hosted_theme"),
            "id_token_lifetime": obj.get("id_token_lifetime"),
            "passage_branding": obj.get("passage_branding"),
            "profile_management": obj.get("profile_management"),
            "public_signup": obj.get("public_signup"),
            "redirect_url": obj.get("redirect_url"),
            "refresh_absolute_lifetime": obj.get("refresh_absolute_lifetime"),
            "refresh_enabled": obj.get("refresh_enabled"),
            "refresh_inactivity_lifetime": obj.get("refresh_inactivity_lifetime"),
            "require_email_verification": obj.get("require_email_verification"),
            "require_identifier_verification": obj.get("require_identifier_verification"),
            "required_identifier": obj.get("required_identifier"),
            "role": obj.get("role"),
            "rsa_public_key": obj.get("rsa_public_key"),
            "secret": obj.get("secret"),
            "session_timeout_length": obj.get("session_timeout_length"),
            "type": obj.get("type"),
            "user_metadata_schema": [UserMetadataField.from_dict(_item) for _item in obj["user_metadata_schema"]] if obj.get("user_metadata_schema") is not None else None,
            "technologies": obj.get("technologies"),
            "element_customization": ElementCustomization.from_dict(obj["element_customization"]) if obj.get("element_customization") is not None else None,
            "element_customization_dark": ElementCustomization.from_dict(obj["element_customization_dark"]) if obj.get("element_customization_dark") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Passage Management API

    Passage's management API to manage your Passage apps and users.

    The version of the OpenAPI document: 1
    Contact: support@passage.id
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from passageidentity.openapi_client.models.web_authn_icons import WebAuthnIcons
from passageidentity.openapi_client.models.web_authn_type import WebAuthnType
from typing import Optional, Set
from typing_extensions import Self

class WebAuthnDevices(BaseModel):
    """
    WebAuthnDevices
    """ # noqa: E501
    created_at: datetime = Field(description="The first time this webAuthn device was used to authenticate the user")
    cred_id: StrictStr = Field(description="The CredID for this webAuthn device")
    friendly_name: StrictStr = Field(description="The friendly name for the webAuthn device used to authenticate")
    id: StrictStr = Field(description="The ID of the webAuthn device used for authentication")
    last_login_at: datetime = Field(description="The last time this webAuthn device was used to authenticate the user")
    type: WebAuthnType
    updated_at: datetime = Field(description="The last time this webAuthn device was updated")
    usage_count: StrictInt = Field(description="How many times this webAuthn device has been used to authenticate the user")
    icons: WebAuthnIcons
    __properties: ClassVar[List[str]] = ["created_at", "cred_id", "friendly_name", "id", "last_login_at", "type", "updated_at", "usage_count", "icons"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of WebAuthnDevices from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of icons
        if self.icons:
            _dict['icons'] = self.icons.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of WebAuthnDevices from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "created_at": obj.get("created_at"),
            "cred_id": obj.get("cred_id"),
            "friendly_name": obj.get("friendly_name"),
            "id": obj.get("id"),
            "last_login_at": obj.get("last_login_at"),
            "type": obj.get("type"),
            "updated_at": obj.get("updated_at"),
            "usage_count": obj.get("usage_count"),
            "icons": WebAuthnIcons.from_dict(obj["icons"]) if obj.get("icons") is not None else None
        })
        return _obj





"""Defines required arguments for creating a Magic Link."""

from typing import Union

from passageidentity.openapi_client.models.magic_link_channel import MagicLinkChannel
from passageidentity.openapi_client.models.magic_link_type import MagicLinkType


class MagicLinkArgsBase:
    """Base class for MagicLinkArgs."""

    type: MagicLinkType
    send: bool


class MagicLinkWithEmailArgs(MagicLinkArgsBase):
    """Arguments for creating a Magic Link with an email."""

    email: str


class MagicLinkWithPhoneArgs(MagicLinkArgsBase):
    """Arguments for creating a Magic Link with a phone number."""

    phone: str


class MagicLinkWithUserArgs(MagicLinkArgsBase):
    """Arguments for creating a Magic Link with a user ID."""

    user_id: str
    channel: MagicLinkChannel


MagicLinkArgs = Union[MagicLinkWithEmailArgs, MagicLinkWithPhoneArgs, MagicLinkWithUserArgs]



"""Provides functions to make HTTP requests with optional API key authorization."""

from __future__ import annotations

import json
from importlib import metadata

import requests

PACKAGE_VERSION = metadata.version("passage-identity")


def get_headers(api_key: str | None = None) -> dict[str, str]:
    """Create a new headers dict with the package version included."""
    headers = {"Passage-Version": f"passage-python {PACKAGE_VERSION}"}
    if api_key:
        headers["Authorization"] = "Bearer " + api_key

    return headers


def get(url: str, api_key: str | None = None) -> requests.Response:
    """Send a GET request with API key in Authorization header if provided."""
    return requests.get(url, headers=get_headers(api_key))  # noqa: S113


def post(url: str, api_key: str | None = None, data: dict | None = None) -> requests.Response:
    """Send a POST request with API key in Authorization header if provided, and the JSON-encoded data in the body."""
    return requests.post(  # noqa: S113
        url,
        headers=get_headers(api_key),
        data=json.dumps(data) if data else None,
    )


def patch(url: str, api_key: str | None = None, data: dict | None = None) -> requests.Response:
    """Send a PATCH request with API key in Authorization header if provided, and the JSON-encoded data in the body."""
    return requests.patch(  # noqa: S113
        url,
        headers=get_headers(api_key),
        data=json.dumps(data) if data else None,
    )


def delete(url: str, api_key: str | None = None) -> requests.Response:
    """Send a DELETE request with API key in Authorization header if provided."""
    return requests.delete(url, headers=get_headers(api_key))  # noqa: S113



# coding: utf-8

"""
    Passage Management API

    Passage's management API to manage your Passage apps and users.

    The version of the OpenAPI document: 1
    Contact: support@passage.id
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FontFamily(str, Enum):
    """
    Body font family
    """

    """
    allowed enum values
    """
    HELVETICA = 'Helvetica'
    ARIAL = 'Arial'
    ARIAL_BLACK = 'Arial Black'
    VERDANA = 'Verdana'
    TAHOMA = 'Tahoma'
    TREBUCHET_MS = 'Trebuchet MS'
    IMPACT = 'Impact'
    GILL_SANS = 'Gill Sans'
    TIMES_NEW_ROMAN = 'Times New Roman'
    GEORGIA = 'Georgia'
    PALATINO = 'Palatino'
    BASKERVILLE = 'Baskerville'
    ANDALÉ_MONO = 'Andalé Mono'
    COURIER = 'Courier'
    LUCIDA = 'Lucida'
    MONACO = 'Monaco'
    BRADLEY_HAND = 'Bradley Hand'
    BRUSH_SCRIPT_MT = 'Brush Script MT'
    LUMINARI = 'Luminari'
    COMIC_SANS_MS = 'Comic Sans MS'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FontFamily from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
Passage Management API

Passage's management API to manage your Passage apps and users.

The version of the OpenAPI document: 1
Contact: support@passage.id
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool

try:
    from typing import Self
except ImportError:
    from typing_extensions import Self


@DeprecationWarning
class UpdatePasskeysAuthMethod(BaseModel):
    """
    UpdatePasskeysAuthMethod
    """  # noqa: E501

    enabled: Optional[StrictBool] = True
    __properties: ClassVar[List[str]] = ["enabled"]

    model_config = {"populate_by_name": True, "validate_assignment": True}

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of UpdatePasskeysAuthMethod from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={},
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of UpdatePasskeysAuthMethod from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {"enabled": obj.get("enabled") if obj.get("enabled") is not None else True}
        )
        return _obj


"""Setup configuration for the Passage Identity Python package."""

from pathlib import Path

import setuptools

with Path("README.md").open(encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="passage-identity",
    version="2.6.0",
    author="Passage by 1Password",
    author_email="support@passage.id",
    description=(
        "Passkey Complete for Python - Integrate into your Python API or service to enable "
        "a completely passwordless standalone auth solution with Passage by 1Password"
    ),
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://docs.passage.id/complete",
    project_urls={
        "Bug Tracker": "https://github.com/passageidentity/.github/blob/main/SUPPORT.md",
    },
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=[
        "passageidentity",
        "passageidentity.models",
        "passageidentity.openapi_client",
        "passageidentity.openapi_client.api",
        "passageidentity.openapi_client.models",
    ],
    package_dir={
        "passageidentity": "passageidentity",
        "passageidentity.models": "passageidentity/models",
        "passageidentity.openapi_client": "passageidentity/openapi_client",
        "passageidentity.openapi_client.api": "passageidentity/openapi_client/api",
        "passageidentity.openapi_client.models": "passageidentity/openapi_client/models",
    },
    install_requires=[
        "cryptography ~= 44.0",  # used by pyjwt
        "pydantic ~= 2.10",  # used by codgen
        "pyjwt ~= 2.9",
        "python-dateutil ~= 2.9",  # used by codegen
        "requests ~= 2.32",
    ],
    extras_require={
        "dev": [
            "pytest ~= 8.3",
            "python-dotenv ~= 1.0",
            "faker ~= 33.1",
            "build ~= 1.2",
            "ruff ~= 0.8",
        ],
    },
    setup_requires=["pytest-runner"],
    tests_require=["pytest"],
    test_suite="tests",
    python_requires=">=3.8",
)



# coding: utf-8

"""
    Passage Management API

    Passage's management API to manage your Passage apps and users.

    The version of the OpenAPI document: 1
    Contact: support@passage.id
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class TtlDisplayUnit(str, Enum):
    """
    Deprecated Property. The preferred unit for displaying the TTL. This value is for display only. * `s` - seconds * `m` - minutes * `h` - hours * `d` - days 
    """

    """
    allowed enum values
    """
    S = 's'
    M = 'm'
    H = 'h'
    D = 'd'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TtlDisplayUnit from a JSON string"""
        return cls(json.loads(json_str))


